<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Fensterrahmen entfernen</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-Weiß</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Auf Fenster umschalten</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Auf Vollbild umschalten</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Das Setup war erfolgreich.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Schließe das Fenster und starte vokoscreenNG erneut.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Have fun with vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installieren Sie einen Dateimanager.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installieren Sie einen Dateimanager.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Die Aufnahme wird nicht gestartet, nicht genügend freier Speicherplatz.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Das Limit für den freien Speicherplatz ist erreicht.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grenze für freien Plattenplatz</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Die Aufnahme wurde gestoppt, nicht genügend freier Speicherplatz.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Kein Dateimanager gefunden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installieren Sie einen Dateimanager.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Quellcode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Quellcode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installieren Sie einen Dateimanager.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Kein Dateimanager gefunden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Bitte installieren Sie einen Dateimanager.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-Weiß</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fensterrahmen entfernen</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameraeinstellungen</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videogröße:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Freier Plattenplatz:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Aufnahmezeit:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Mauszeiger nicht aufnehmen</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Stunde</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Timer starten</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Aufnahme stoppen nach</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopfad</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grenze für freien Plattenplatz</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Im Benachrichtigungsfeld anzeigen</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekunden vor der Aufnahme warten</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Nach Aktualisierungen suchen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Letzte Aufnahme abspielen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimiert beim Start der Aufzeichnung</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Startet minimiert</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-Weiß</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fensterrahmen entfernen</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Alle Einstellungen beim nächsten Start zurücksetzen</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Erstelle Bilder von Tabs</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Lizenz Information</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Ein</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Globale Tastenkombinationen</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Zugewiesene Tastenkombinationen.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Tastaturkürzel nicht zugewiesen oder mehrfach zugewiesen.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Wenn es zugewiesen anzeigt, aber nicht funktioniert, wird es von einem anderen Programm verwendet.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Snapshot</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Bilderpfad</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Dieses Fenster ausblenden</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Sekunden warten, bevor die Aufnahme beginnt</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Erstelle Bilder von Tabs</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Lizenz Information</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Ein</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Aufnahmezeit:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videogröße:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Freier Plattenplatz:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Mauszeiger nicht aufnehmen</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopfad</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertiert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grau</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Schwarz-Weiß</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fensterrahmen entfernen</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekunden vor der Aufnahme warten</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Dieses Fenster ausblenden</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Sekunden warten, bevor die Aufnahme beginnt</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright und Lizenz von Bildern</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
</context>
</TS>